==> igniteui-react-core-18.2.0-beta.2.tgz: package/esm2015/lib/WebPageCancellableEventArgsDescriptionMetadata.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { Base, String_$type, markType } from "./type";
import { Dictionary$2 } from "./Dictionary$2";
import { WebPageCancellableEventArgsDetailDescriptionMetadata } from "./WebPageCancellableEventArgsDetailDescriptionMetadata";
import { WebPageCancellableEventArgsDescription } from "./WebPageCancellableEventArgsDescription";
/**
 * @hidden
 */
export let WebPageCancellableEventArgsDescriptionMetadata = /*@__PURE__*/ (() => {
    class WebPageCancellableEventArgsDescriptionMetadata extends Base {
        static b(a) {
            if (WebPageCancellableEventArgsDescriptionMetadata.a == null) {
                WebPageCancellableEventArgsDescriptionMetadata.a = new Dictionary$2(String_$type, String_$type, 0);
                WebPageCancellableEventArgsDescriptionMetadata.c(WebPageCancellableEventArgsDescriptionMetadata.a);
            }
            if (a.k(WebPageCancellableEventArgsDescriptionMetadata.a)) {
                return;
            }
            a.ab(WebPageCancellableEventArgsDescriptionMetadata.a);
            WebPageCancellableEventArgsDetailDescriptionMetadata.d(a);
        }
        static c(a) {
            a.item("__qualifiedNameTS", "String:PageCancellableEventArgs");
            a.item("__isPlainObject", "Boolean");
            a.item("__skipSuffix", "Boolean");
            a.item("Detail", "ExportedType:WebPageCancellableEventArgsDetail");
        }
        static d(a) {
            WebPageCancellableEventArgsDescriptionMetadata.b(a);
            a.ad("WebPageCancellableEventArgs", () => new WebPageCancellableEventArgsDescription());
            a.ac("WebPageCancellableEventArgs", WebPageCancellableEventArgsDescriptionMetadata.a);
        }
    }
    WebPageCancellableEventArgsDescriptionMetadata.$t = /*@__PURE__*/ markType(WebPageCancellableEventArgsDescriptionMetadata, 'WebPageCancellableEventArgsDescriptionMetadata');
    WebPageCancellableEventArgsDescriptionMetadata.a = null;
    return WebPageCancellableEventArgsDescriptionMetadata;
})();

==> igniteui-react-core-18.7.0-beta.2.tgz: package/esm2015/lib/WebPageCancellableEventArgsDescriptionMetadata.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { Base, String_$type, markType } from "./type";
import { Dictionary$2 } from "./Dictionary$2";
import { WebPageCancellableEventArgsDetailDescriptionMetadata } from "./WebPageCancellableEventArgsDetailDescriptionMetadata";
import { WebPageCancellableEventArgsDescription } from "./WebPageCancellableEventArgsDescription";
/**
 * @hidden
 */
export let WebPageCancellableEventArgsDescriptionMetadata = /*@__PURE__*/ (() => {
    class WebPageCancellableEventArgsDescriptionMetadata extends Base {
        static b(a) {
            if (WebPageCancellableEventArgsDescriptionMetadata.a == null) {
                WebPageCancellableEventArgsDescriptionMetadata.a = new Dictionary$2(String_$type, String_$type, 0);
                WebPageCancellableEventArgsDescriptionMetadata.c(WebPageCancellableEventArgsDescriptionMetadata.a);
            }
            if (a.k(WebPageCancellableEventArgsDescriptionMetadata.a)) {
                return;
            }
            a.ac(WebPageCancellableEventArgsDescriptionMetadata.a);
            WebPageCancellableEventArgsDetailDescriptionMetadata.d(a);
        }
        static c(a) {
            a.item("__qualifiedNameTS", "String:PageCancellableEventArgs");
            a.item("__packageNameWC", "String:grids");
            a.item("__skipModuleRegisterWebComponents", "Boolean");
            a.item("__importOverrideWebComponents", "String:igniteui-webcomponents-grids/grids/combined");
            a.item("__importTypesWebComponents", "String:igniteui-webcomponents-grids/grids");
            a.item("__marshalByValue", "Boolean");
            a.item("__skipSuffix", "Boolean");
            a.item("Detail", "ExportedType:WebPageCancellableEventArgsDetail");
        }
        static d(a) {
            WebPageCancellableEventArgsDescriptionMetadata.b(a);
            a.ae("WebPageCancellableEventArgs", () => new WebPageCancellableEventArgsDescription());
            a.ad("WebPageCancellableEventArgs", WebPageCancellableEventArgsDescriptionMetadata.a);
        }
    }
    WebPageCancellableEventArgsDescriptionMetadata.$t = /*@__PURE__*/ markType(WebPageCancellableEventArgsDescriptionMetadata, 'WebPageCancellableEventArgsDescriptionMetadata');
    WebPageCancellableEventArgsDescriptionMetadata.a = null;
    return WebPageCancellableEventArgsDescriptionMetadata;
})();
